Learn R Programming

ternarynet (version 1.16.0)

tnetfit: Ternary Network Fitting

Description

This function fits a ternary network based on perturbation experiments.

Usage

tnetfit(steadyStateObj, perturbationObj, params=ternaryFitParameters(), xSeed=NA)

Arguments

steadyStateObj
a matrix of steady gene expression observations from a perturbation experiment. Rows are genes and columns are experiments.
perturbationObj
a matrix of perturbation experiments. Rows are genes and columns are experiments.
params
a ternaryFitParameters object
xSeed
an integer random seed. If NA, a random seed is generated.

Value

The function returns a ternaryFit object.

See Also

Almudevar A, McCall MN, McMurray H, Land H (2011). Fitting Boolean Networks from Steady State Perturbation Data, Statistical Applications in Genetics and Molecular Biology, 10(1): Article 47.

Examples

Run this code
ssObj <- matrix(c(1,1,1,0,1,1,0,0,1),nrow=3)
pObj <- matrix(c(1,0,0,0,1,0,0,0,1),nrow=3)
rownames(ssObj) <- rownames(pObj) <- colnames(ssObj) <- colnames(pObj) <- c("Gene1","Gene2","Gene3")
tnfitObj <- tnetfit(ssObj, pObj)

Run the code above in your browser using DataLab